@@ -53,7 +53,7 @@
 #include "DwmRDAPBootstrap.hh"
 #include "DwmRDAPQuery.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/dwmrdap/dwmrdap.cc 12239 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/dwmrdap/dwmrdap.cc 12239 $");
 
 using namespace std;
 using namespace Dwm;
