@@ -53,7 +53,7 @@
 #include "DwmRDAPRequestMessage.hh"
 #include "DwmRDAPResponseMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/dwmrdapc/dwmrdapc.cc 12126 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/dwmrdapc/dwmrdapc.cc 12126 $");
 
 using namespace std;
 using namespace Dwm;
