@@ -62,7 +62,7 @@ extern "C" {
 #include "DwmRDAPResponseMessage.hh"
 #include "DwmRDAPServer.hh"
 
-static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/dwmrdapd/DwmRDAPResponder.cc 12124 $");
+static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmRDAP/trunk/apps/dwmrdapd/DwmRDAPResponder.cc 12124 $");
 
 using namespace std;
 
