@@ -61,7 +61,7 @@ extern "C" {
 #include "libDwmRDAPPortability.hh"
 #include "DwmRDAPServer.hh"
 
-static const Dwm::SvnTag  svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/dwmrdapd/DwmRDAPServer.cc 12106 $");
+static const Dwm::SvnTag  svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/dwmrdapd/DwmRDAPServer.cc 12106 $");
 
 using namespace std;
 
