@@ -42,7 +42,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmRDAPServerConfig.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/dwmrdapd/DwmRDAPServerConfig.cc 12073 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/dwmrdapd/DwmRDAPServerConfig.cc 12073 $");
 
 using namespace std;
 
