@@ -60,7 +60,7 @@ extern "C" {
 #include "DwmRDAPServerConfig.hh"
 #include "DwmRDAPServer.hh"
 
-static const Dwm::SvnTag  svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/dwmrdapd/dwmrdapd.cc 12080 $");
+static const Dwm::SvnTag  svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/dwmrdapd/dwmrdapd.cc 12080 $");
 
 using namespace std;
 using namespace Dwm;
