@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/getpfx2as/getpfx2as.cc 12241 $
+// @(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/getpfx2as/getpfx2as.cc 12241 $
 // @(#) $Id: getpfx2as.cc 12241 2023-10-26 17:59:43Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
@@ -62,7 +62,7 @@ extern "C" {
 #include "DwmWebUtils.hh"
 #include "DwmWebUtilsUrl.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/getpfx2as/getpfx2as.cc 12241 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/getpfx2as/getpfx2as.cc 12241 $");
 
 using namespace std;
 using namespace boost::beast;
