@@ -49,7 +49,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/ipdeny2db/ipdeny2db.cc 9406 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/ipdeny2db/ipdeny2db.cc 9406 $");
 
 using namespace std;
 using namespace Dwm;
