@@ -43,7 +43,7 @@
 #include "DwmSysLogger.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/rdapdb2json/rdapdb2json.cc 8959 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/rdapdb2json/rdapdb2json.cc 8959 $");
 
 using namespace std;
 using namespace Dwm;
