@@ -43,7 +43,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/rdapdb2pf/rdapdb2pf.cc 12241 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/rdapdb2pf/rdapdb2pf.cc 12241 $");
 
 using namespace std;
 using namespace Dwm;
