@@ -45,7 +45,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/apps/rdapjson2db/rdapjson2db.cc 12077 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/apps/rdapjson2db/rdapjson2db.cc 12077 $");
 
 using namespace std;
 using namespace Dwm;
