@@ -50,7 +50,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmCountryCodes.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmCountryCodes.cc 12073 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmCountryCodes.cc 12073 $");
 
 using namespace std;
 
