@@ -60,7 +60,7 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmIpv4CountryDb.cc 12241 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmIpv4CountryDb.cc 12241 $");
 
 using namespace std;
 
