@@ -50,7 +50,7 @@
 #include "DwmWebUtilsUrl.hh"
 #include "DwmRDAPBootstrap.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmRDAPBootstrap.cc 12122 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmRDAPBootstrap.cc 12122 $");
 
 using namespace std;
 
