@@ -44,7 +44,7 @@
 #include "DwmSysLogger.hh"
 #include "DwmRDAPFetcher.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmRDAPFetcher.cc 12123 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmRDAPFetcher.cc 12123 $");
 
 using namespace std;
 
