@@ -49,7 +49,7 @@
 #include "DwmRDAPBootstrap.hh"
 #include "DwmRDAPQuery.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmRDAPQuery.cc 12078 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmRDAPQuery.cc 12078 $");
 
 using namespace std;
 
