@@ -47,7 +47,7 @@
 #include "DwmWebUtilsUrl.hh"
 #include "DwmRDAPQuerySessions.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmRDAPQuerySessions.cc 12078 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmRDAPQuerySessions.cc 12078 $");
 
 using namespace std;
 
