@@ -43,7 +43,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmRDAPRequestMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmRDAPRequestMessage.cc 12117 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmRDAPRequestMessage.cc 12117 $");
 
 using namespace std;
 
