@@ -43,7 +43,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmRDAPResponse.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmRDAPResponse.cc 12077 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmRDAPResponse.cc 12077 $");
 
 using namespace std;
 
