@@ -43,7 +43,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmRDAPResponseMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/src/DwmRDAPResponseMessage.cc 12118 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/src/DwmRDAPResponseMessage.cc 12118 $");
 
 using namespace std;
 
