@@ -52,7 +52,7 @@ extern "C" {
 #include "DwmUnitAssert.hh"
 #include "DwmCountryCodes.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/tests/TestCountryCodes.cc 9458 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/tests/TestCountryCodes.cc 9458 $");
 
 using namespace std;
 using namespace Dwm;
