@@ -49,7 +49,7 @@
 #include "DwmRDAPBootstrap.hh"
 #include "DwmRDAPQuery.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.4/tests/TestRDAPQuery.cc 12239 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/trunk/tests/TestRDAPQuery.cc 12239 $");
 
 using namespace std;
 using namespace Dwm;
